@@ -4,7 +4,7 @@
 
 #include "seccomon.h"
 #include "nss.h"
-#include "key.h"
+#include "keyhi.h"
 #include "cert.h"
 #include "pk11func.h"
 #include "secmod.h"
@@ -1007,7 +1007,7 @@ processChallengeResponse(CGIVarTable *varTable, const char *certRepContent)
             rv = ERROR_RETRIEVING_CLIENT_RESPONSE_TO_CHALLENGE;
             goto loser;
         }
-        sprintf(cgiChalVar, "chal%d", i + 1);
+        snprintf(cgiChalVar, sizeof(cgiChalVar), "chal%d", i + 1);
         formChalValue = CGITableFindValue(varTable, cgiChalVar);
         if (formChalValue == NULL) {
             rv = REQ_CGI_VAR_NOT_PRESENT;
